# Author: Yulin Wang (yulinwang@seu.edu.cn)
# School of Mechanical Engineering, Southeast University, China

import numpy as np 

def clear_sym(model_i_):
    """ This function removes all rotational symmetry information from model_i_.  
    Parameters:  
        model_i_: Object model information.  
    """
    
    mks_ = []
    mks = model_i_.keys()
    for key_i in mks:
        mks_.append(key_i)
    for key_i in mks_:
        if key_i in ["No Sym", "sym_colors", "symmetries_continuous","symmetries_continuous_2","symmetries_continuous_3", "symmetries_discrete"]:
            del model_i_[key_i]
            
sym_axis_temp = {}

sym_axis_temp["P(4): Tetrahedral Item"] = \
    [
        {
            "axis_l": [
                [
                    -6.149999825316301e-06,
                    0.9428078580169925,
                    -0.33333668088523977
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    -0.8164965809508006,
                    -0.4714045208045031,
                    -0.33333333325776127
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    0.8164924809303754,
                    -0.47140925506463566,
                    -0.3333366808852066
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    1.844981418474448e-05,
                    1.065200540799244e-05,
                    0.9999999997730696
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    -0.7071121072091718,
                    0.4082390655682039,
                    -0.5773502690587443
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    0.707101455123752,
                    0.4082452154600121,
                    -0.5773589665155302
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    -1.0652005185642133e-05,
                    -0.8164965809508851,
                    -0.5773502690586102
                ]
            ],
            "num": 1
        }
    ]

sym_axis_temp["P(8): Octahedral Item"] = \
    [
        {
            "axis_l": [
                [
                    -5.024295867788089e-16,
                    3.4149510976372166e-15,
                    -1.0
                ]
            ],
            "num": 3
        },
        {
            "axis_l": [
                [
                    0.7071067811865452,
                    0.7071067811865498,
                    6.5559654569303055e-15
                ]
            ],
            "num": 3
        },
        {
            "axis_l": [
                [
                    0.707106781186549,
                    -0.7071067811865461,
                    -4.124729972072426e-16
                ]
            ],
            "num": 3
        },
        {
            "axis_l": [
                [
                    0.49999999999999917,
                    0.5000000000000052,
                    -0.7071067811865446
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    1.0,
                    -6.508682481864973e-16,
                    4.344105178438587e-15
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    0.500000000000003,
                    -0.4999999999999988,
                    -0.7071067811865464
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    4.9737991503207065e-15,
                    -1.0,
                    -1.9274227342706756e-15
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    0.49999999999999983,
                    -0.5000000000000046,
                    0.7071067811865446
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    -0.5,
                    -0.4999999999999966,
                    -0.7071067811865499
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    0.8164965809277284,
                    1.4277269532860472e-15,
                    -0.5773502691896224
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    8.702335715267326e-16,
                    -0.8164965809277286,
                    0.5773502691896224
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    3.916051071870301e-15,
                    -0.8164965809277249,
                    -0.5773502691896275
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    -0.8164965809277247,
                    3.022022051122131e-15,
                    -0.5773502691896277
                ]
            ],
            "num": 2
        }
    ]

sym_axis_temp["P(20): Icosahedral Item"] = \
    [
        {
            "axis_l": [
                [
                    0.5257311121191329,
                    0.7236067977499804,
                    -0.4472135954999565
                ]
            ],
            "num": 4
        },
        {
            "axis_l": [
                [
                    -7.459279159640958e-16,
                    -8.194850147527737e-15,
                    -1.0
                ]
            ],
            "num": 4
        },
        {
            "axis_l": [
                [
                    -0.5257311121191354,
                    0.7236067977499785,
                    -0.4472135954999568
                ]
            ],
            "num": 4
        },
        {
            "axis_l": [
                [
                    0.8506508083520405,
                    0.2763932022500171,
                    0.4472135954999592
                ]
            ],
            "num": 4
        },
        {
            "axis_l": [
                [
                    3.666680770089635e-15,
                    0.8944271909999155,
                    0.4472135954999587
                ]
            ],
            "num": 4
        },
        {
            "axis_l": [
                [
                    0.8506508083520417,
                    -0.27639320225002506,
                    -0.4472135954999523
                ]
            ],
            "num": 4
        },
        {
            "axis_l": [
                [
                    0.3090169943749469,
                    0.42532540417601644,
                    -0.850650808352042
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    -0.30901699437494917,
                    0.4253254041760152,
                    -0.8506508083520417
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    -1.463798537196921e-15,
                    0.8506508083520408,
                    -0.5257311121191323
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    0.5000000000000008,
                    0.16245984811645234,
                    0.8506508083520397
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    0.5000000000000021,
                    0.6881909602355846,
                    0.5257311121191347
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    1.3086657811925204e-15,
                    0.5257311121191359,
                    0.8506508083520385
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    0.8090169943749501,
                    0.2628655560595652,
                    -0.5257311121191305
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    0.5000000000000011,
                    -0.16245984811646047,
                    -0.850650808352038
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    -0.8090169943749461,
                    0.587785252292475,
                    2.1956978057953753e-16
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    -0.8090169943749482,
                    0.2628655560595652,
                    -0.5257311121191334
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    -1.0,
                    2.278036473512708e-15,
                    -8.782791223181526e-16
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    -0.4999999999999966,
                    0.6881909602355897,
                    0.5257311121191331
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    0.30901699437494856,
                    0.9510565162951533,
                    1.86634313492607e-15
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    -0.3090169943749463,
                    0.9510565162951541,
                    1.6467733543465354e-15
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    0.8090169943749482,
                    0.5877852522924721,
                    1.756558244636306e-15
                ]
            ],
            "num": 1
        },
        {
            "axis_l": [
                [
                    -1.3710785892546703e-15,
                    0.6070619982066843,
                    -0.7946544722917678
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    0.3568220897730914,
                    0.49112347318842287,
                    0.7946544722917657
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    0.5773502691896275,
                    0.1875924740850754,
                    -0.7946544722917659
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    -0.9341723589627153,
                    0.3035309991033443,
                    -0.18759247408507976
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    -0.5773502691896264,
                    0.18759247408507534,
                    -0.7946544722917669
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    -0.35682208977308877,
                    0.49112347318842686,
                    0.7946544722917643
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    5.288445987125142e-16,
                    0.9822469463768464,
                    -0.18759247408507806
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    0.9341723589627173,
                    0.30353099910334014,
                    -0.18759247408507676
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    0.5773502691896271,
                    0.7946544722917649,
                    0.18759247408508173
                ]
            ],
            "num": 2
        },
        {
            "axis_l": [
                [
                    0.5773502691896262,
                    -0.7946544722917664,
                    -0.1875924740850771
                ]
            ],
            "num": 2
        }
    ]
    
def get_sym_axis_temp(sym_key, N=2):
    if sym_key == 'None' or sym_key is None:
        return None
    if sym_key in sym_axis_temp:
        return sym_axis_temp[sym_key]
    else:
        if sym_key == "D(=1): n-fold Pyramidal Item":
            l_ = []
            l_.append(
                {
                    "axis_l": [
                        [
                            0.0,
                            0.0,
                            1.0
                        ]
                    ],
                    "num": N - 1
                }
            )
            return l_

        elif sym_key == "D(>1): n-fold Prismatic Item":
            l_ = []
            l_.append(
                        {
                            "axis_l": [
                                [
                                    0.0,
                                    0.0,
                                    1.0
                                ]
                            ],
                            "num": N - 1
                        }
                    )
            for i_ in range(N):
                a_ = i_/N * np.pi
                l_.append(
                            {
                                "axis_l": [
                                    [
                                        np.cos(a_),
                                        np.sin(a_),
                                        0.0
                                    ]
                                ],
                                "num": 1
                            }
                        )
            return l_
        else:
            return None
    

    
    
    
    
    
